#ifdef DEBUG_LOG_SD

#define BOOT                0
#define DCF77_RECEIVED      1
#define RTCC_TIME           2
#define METEO               3
#define METEO_EEPROM        4
#define START_DCF           5
#define NEW_DAY             6
#define EEPROM_VARIABLES    7
#define FIRST_START         8
#define METEO_TIME          9
#define WIFI_CON            10
#define WIFI_NO_CON         11
#define WIFI_SERVER         12
#define WIFI_SSID_TEST      13
#define NEW_CON             14
#define CLOSED_CON          15
#define INCOMING_DATA       16
#define START_RECORD_LOG    17
#define READ_LOG            18
#define REMOTE_DISCON       19
#define REMOTE_CONNECT      20
#define SENSOR_ANOMALY_LOC  21
#define SENSOR_ANOMALY_REM  22
#define DCF77_STOPPED       23
#define TIME_START_STATISTIC          24
#define HMTRP_DATA          25
#define REMOTE_ELSE         26
#define REMOTE_SETUP_SENS   27
#define REMOTE_TEST_SENS    28
#define WIFI_TIMEOUT        29

#define DCF77_RECEIVED_SINGLE       30

/* PROTOTIPI ================================================================================================================================== */
void f_write_rtcc_date_time(void);
void f_write_rtcc_date_time_start(void);
void f_write_dcf77_date_time (dcf77_decoded_data _time);

unsigned char connection_log = 0;

/* ============================================================================================================================================= /
 * FUNCTION:    Write_log
 * Input:       _section: parte di log da scrivere (unsigned char)
 *
 * Overview:    Scrive il file LOG.txt su SD con informazioni di debug richieste
/* ============================================================================================================================================ */
void Write_log(unsigned char _section){
    unsigned char _temp = 0;
    unsigned char _temp_2 = 0;
    unsigned char _eeprom_readed = 0;
    unsigned int _eeprom_addr = 0;
    unsigned int _i = 0;
    
    if (f_mount(&sd_card, "", 1) == FR_OK) {                                            // Mount SD
        if (f_open(&file, "LOG.txt", FA_OPEN_ALWAYS | FA_READ | FA_WRITE) == FR_OK) {	// Apertura file LOG
            f_lseek(&file, file.fsize);                                                 // Lettura ultimo settore scritto

            switch (_section){
                case BOOT:
                    f_write(&file, "\r\nAVVIO\r\n", 9, &bw);                                    
                    f_write(&file, "RCON= ", 6, &bw);   
                    for (unsigned char _i=0; _i<8; _i++){
                        _temp = (RCON >> 7 -_i) & 0b0000001;
                        _temp += '0';
                        f_write(&file, &_temp, 1, &bw);   
                    }
                    f_write(&file, "\r\n--------------------------------------------------------------------------------", 82, &bw);
                    break;
                case START_DCF:
                    f_write_rtcc_date_time();
                    f_write(&file, "\r\nDCF77 Started", 15, &bw);
                    f_write(&file, "\r\n--------------------------------------------------------------------------------", 82, &bw);
                    break;
                case DCF77_RECEIVED:
                    f_write(&file, "DCF77_received_1: ", 18, &bw);                      
                    f_write_dcf77_date_time(dcf77_time_0);
                    f_write(&file, "\r\nDCF77_received_2: ", 20, &bw);                      
                    f_write_dcf77_date_time(dcf77_time_1);
                    f_write(&file, "\r\nDCF77_received_3: ", 20, &bw);                      
                    f_write_dcf77_date_time(dcf77_time_2);
                    f_write(&file, "\r\n--------------------------------------------------------------------------------", 82, &bw);
                    break;
                case RTCC_TIME:
                    f_write(&file, "DCF77 Sync: \r\n", 14, &bw);                            
                    f_write_rtcc_date_time();
                    f_write(&file, "\r\n--------------------------------------------------------------------------------", 82, &bw);
                    break;                    
                case METEO:
                    f_write_rtcc_date_time();
                    f_write(&file, "\r\nMeteo Decoded: ", 17, &bw);                         

                    _temp = (meteo_fc_decoded.day_fc / 10) +'0';
                    f_write(&file, &_temp, 1, &bw);
                    _temp = (meteo_fc_decoded.day_fc % 10) + '0';
                    f_write(&file, &_temp, 1, &bw);
                    f_write(&file, " ", 1, &bw);

                    _temp =  (meteo_fc_decoded.night_fc / 10) + '0';
                    f_write(&file, &_temp, 1, &bw);
                    _temp = (meteo_fc_decoded.night_fc % 10) + '0';
                    f_write(&file, &_temp, 1, &bw);
                    f_write(&file, " ", 1, &bw);

                    _temp = (meteo_fc_decoded.extreme_w_wind_dir / 10) + '0';
                    f_write(&file, &_temp, 1, &bw);
                    _temp = (meteo_fc_decoded.extreme_w_wind_dir % 10) + '0';
                    f_write(&file, &_temp, 1, &bw);  
                    f_write(&file, " ", 1, &bw);

                    _temp = meteo_fc_decoded.rain_pr_wind_str + '0';
                    f_write(&file, &_temp, 1, &bw);   
                    f_write(&file, " ", 1, &bw);

                    _temp = meteo_fc_decoded.anomaly + '0';
                    f_write(&file, &_temp, 1, &bw);   
                    f_write(&file, " ", 1, &bw);
                    
                    if (meteo_fc_decoded.temp_fc < 0) {
                        _temp = (~meteo_fc_decoded.temp_fc)+1;
                        f_write(&file, "-", 1, &bw);
                    } else
                        _temp = meteo_fc_decoded.temp_fc;
                    
                    _temp_2 = (_temp/10) + '0';
                    f_write(&file, &_temp_2, 1, &bw);
                    _temp_2 = (_temp % 10) + '0';
                    f_write(&file, &_temp_2, 1, &bw);
                    f_write(&file, " ", 1, &bw);

                    _temp = meteo_fc_decoded.decoder_status + '0';
                    f_write(&file, &_temp, 1, &bw); 
                    f_write(&file, "\r\n--------------------------------------------------------------------------------", 82, &bw);
                    break;    
                    
                case METEO_EEPROM:
                    _eeprom_addr = EEPROM_FC_D1_ADDRESS;
                    f_write(&file, "DUMP EEPROM METEO", 17, &bw);
                    for (unsigned char _x = 0; _x < 4; _x++){
                        f_write(&file, "\r\n", 2, &bw);
                        for (unsigned char _i = 0; _i < 16; _i++){
                            _eeprom_readed = EEPROM_read(_eeprom_addr);
                            _temp = (_eeprom_readed >> 4) & 0x0F;
                                if (_temp < 0x0A)
                                    _temp += '0';
                                else 
                                    _temp += 0x37;   
                                f_write(&file, &_temp, 1, &bw);
                                _temp = (_eeprom_readed) & 0x0F;
                                if (_temp < 0x0A)
                                    _temp += '0';
                                else 
                                    _temp += 0x37; 
                                f_write(&file, &_temp, 1, &bw);
                                f_write(&file, " ", 1, &bw);
                            _eeprom_addr++;
                        }
                    }
                    f_write(&file, "\r\n--------------------------------------------------------------------------------", 82, &bw);
                    break;
                    
                case EEPROM_VARIABLES:
                    _eeprom_addr = EEPROM_TOUCH_POINT_1_X_ADDRESS;
                    f_write(&file, "DUMP EEPROM AVVIO", 17, &bw);
                    
                    for (unsigned char _x = 0; _x < 6; _x++){
                        f_write(&file, "\r\n", 2, &bw);
                        for (unsigned char _i = 0; _i < 16; _i++){
                            _eeprom_readed = EEPROM_read(_eeprom_addr);
                            _temp = (_eeprom_readed >> 4) & 0x0F;
                            if (_temp < 0x0A)
                                _temp += '0';
                            else 
                                _temp += 0x37;   
                            f_write(&file, &_temp, 1, &bw);
                            
                            _temp = (_eeprom_readed) & 0x0F;
                            if (_temp < 0x0A)
                                _temp += '0';
                            else 
                                _temp += 0x37; 
                            f_write(&file, &_temp, 1, &bw);
                            f_write(&file, " ", 1, &bw);
                            _eeprom_addr++;
                        }
                    }
                   f_write(&file, "\r\n--------------------------------------------------------------------------------", 82, &bw);
                    break;

                case NEW_DAY:
                    f_write_rtcc_date_time();
                    f_write(&file, "\r\n********************************************************************************", 82, &bw);
                    break;
                case FIRST_START:    
                    f_write(&file, "Primo avvio dopo programmazione", 31, &bw);
                    break;
                case METEO_TIME:
                    f_write_rtcc_date_time();
                    
                    f_write(&file, "\r\nZona Meteo: ", 14, &bw);

                    _temp = (meteo_zone / 10) + '0';
                    f_write(&file, &_temp, 1, &bw);
                    _temp = (meteo_zone % 10) + '0';
                    f_write(&file, &_temp, 1, &bw);
                    
                    f_write(&file, "\r\nOre avvio meteo: ", 19, &bw);
                    
                    for (unsigned char _i = 0; _i < 8; _i++){
                        _temp = (hour_meteo[_i] / 10) + '0';
                        f_write(&file, &_temp, 1, &bw);
                        _temp = (hour_meteo[_i] % 10) + '0';
                        f_write(&file, &_temp, 1, &bw);
                        
                        f_write(&file, " ", 1, &bw);
                    }
                    
                    f_write(&file, "\r\nMinuti avvio meteo: ", 22, &bw);
                                            
                    _temp = (minute_meteo / 10) + '0';
                    f_write(&file, &_temp, 1, &bw);
                    _temp = (minute_meteo % 10) + '0';
                    f_write(&file, &_temp, 1, &bw);
                    
                    f_write(&file, "\r\n--------------------------------------------------------------------------------", 82, &bw);
                    break;
                case WIFI_CON:
                    f_write(&file, "WiFi: Connesso\r\nSSID: ", 22, &bw);
                    _i = 0;                                 
                    
                    ESP8266_check_ap_con(ESP8266_CURRENT_VALUE, ESP8266_DEF_TIMEOUT);
                    
                    while (esp8266_buffer[_i] != ','){                                           
                        f_write(&file, &esp8266_buffer[_i], 1, &bw);
                        _i++;
                    }
                    f_write(&file, "\r\n--------------------------------------------------------------------------------", 82, &bw);
                    break;
                case WIFI_NO_CON:
                    f_write(&file, "WiFi: non connesso", 18, &bw);
                    f_write(&file, "\r\n--------------------------------------------------------------------------------", 82, &bw);
                    break;
                case WIFI_SERVER:
                    f_write_rtcc_date_time();
                    f_write(&file, "\r\nServer: ", 10, &bw);
                    if (server_status == 0)
                        f_write(&file, "Disattivo", 9, &bw);
                    else if (server_status == 1){
                        f_write(&file, "Attivo, Porta: ", 15, &bw);
                        _i = 0;
                        while (port[_i] != '\0'){
                            f_write(&file, &port[_i], 1, &bw);
                            _i++;
                        }
                    } else if (server_status == 0xFE)
                        f_write(&file, "Time out", 8, &bw);
                    else if (server_status == 0xFF)
                        f_write(&file, "Risposta non gestita", 20, &bw);
                    
                    f_write(&file, "\r\n--------------------------------------------------------------------------------", 82, &bw);
                    break;
                case WIFI_SSID_TEST:
                    f_write_rtcc_date_time();
                    f_write(&file, "\r\nTest nuova SSID selezionata", 29, &bw);
                    break;
                case NEW_CON:
                    f_write_rtcc_date_time();
                    f_write(&file, "\r\nNuova connessione in ingresso, connessioni attive: ", 53, &bw);
                    _temp = active_conn + '0';
                    f_write(&file, &_temp, 1, &bw);
                    f_write(&file, "\r\n--------------------------------------------------------------------------------", 82, &bw);
                    break;
                case CLOSED_CON:
                    f_write_rtcc_date_time();
                    f_write(&file, "\r\nConnessione chiusa, connessioni attive: ", 42, &bw);
                    _temp = active_conn + '0';
                    f_write(&file, &_temp, 1, &bw);
                    f_write(&file, "\r\n--------------------------------------------------------------------------------", 82, &bw);
                    break;
                case INCOMING_DATA:
                    f_write_rtcc_date_time();
                    f_write(&file, "\r\nDati in arrivo da connessione ", 32, &bw);
//                    _temp = (_data & 0x0F) + '0';
                    _temp = (connection_log) + '0';
                    f_write(&file, &_temp, 1, &bw);
//                    f_write(&file, "\r\n", 2, &bw);
                    
                    /*
                    _i = 0;
                    
                    while (esp8266_buffer[_i] != '\0' && _i < ESP8266_BUFFER_LENGTH){
                        f_write(&file, &esp8266_buffer[_i], 1, &bw);
                        _i++;
                    }
                    */
                    
                    if (esp8266_buffer[0] == 'A')
                        f_write(&file, "\r\nRichiesta dati in tempo reale", 31, &bw);
                    else if (esp8266_buffer[0] == 'B')
                        f_write(&file, "\r\nRichiesta dati log sensori locali", 35, &bw);                    
                    else if (esp8266_buffer[0] == 'C')
                        f_write(&file, "\r\nRichiesta dati log sensori remoti", 35, &bw);
                    else if (esp8266_buffer[0] == 'D')
                        f_write(&file, "\r\nStart/Stop salvataggio log sensori", 36, &bw);                    
                    else if (esp8266_buffer[0] == 'E')
                        f_write(&file, "\r\nRiprendi salvataggio log sensori", 34, &bw);                    
                    else if (esp8266_buffer[0] == 'F')                                  
                        f_write(&file, "\r\nInvio Debug LOG", 17, &bw);
                        
                    f_write(&file, "\r\n--------------------------------------------------------------------------------", 82, &bw);
                    break;
                case START_RECORD_LOG:
                    f_write_rtcc_date_time();
                    f_write(&file, "\r\nAvvio registrazione LOG sensori. Indice: ", 43, &bw);
                    _temp = (eeprom_log_index >> 4) & 0x0F;
                    if (_temp < 0x0A)
                        _temp += '0';
                    else 
                        _temp += 0x37;   
                    f_write(&file, &_temp, 1, &bw);
                    
                    _temp = eeprom_log_index & 0x0F;
                    if (_temp < 0x0A)
                        _temp += '0';
                    else 
                        _temp += 0x37;   
                    f_write(&file, &_temp, 1, &bw);
                    f_write(&file, "\r\n--------------------------------------------------------------------------------", 82, &bw);
                    break;
                case READ_LOG:
                    f_write_rtcc_date_time();
                    f_write(&file, "\r\nLettura LOG sensori. Primo indice B1: ", 41, &bw);
                    _temp = (EEPROM_I2C_read(EEPROM_I2C_DEV_ADDR_B1,0x00) >> 4) & 0x0F;
                    if (_temp < 0x0A)
                        _temp += '0';
                    else 
                        _temp += 0x37;   
                    f_write(&file, &_temp, 1, &bw);
                    
                    _temp = EEPROM_I2C_read(EEPROM_I2C_DEV_ADDR_B1,0x00) & 0x0F;
                    if (_temp < 0x0A)
                        _temp += '0';
                    else 
                        _temp += 0x37;   
                    f_write(&file, &_temp, 1, &bw);
                    f_write(&file, "\r\nLettura LOG sensori. Primo indice B2: ", 41, &bw);
                    _temp = (EEPROM_I2C_read(EEPROM_I2C_DEV_ADDR_B2,0x00) >> 4) & 0x0F;
                    if (_temp < 0x0A)
                        _temp += '0';
                    else 
                        _temp += 0x37;   
                    f_write(&file, &_temp, 1, &bw);
                    
                    _temp = EEPROM_I2C_read(EEPROM_I2C_DEV_ADDR_B2,0x00) & 0x0F;
                    if (_temp < 0x0A)
                        _temp += '0';
                    else 
                        _temp += 0x37;   
                    f_write(&file, &_temp, 1, &bw);
                    f_write(&file, "\r\n--------------------------------------------------------------------------------", 82, &bw);
                    break;
                case REMOTE_DISCON:
                    f_write_rtcc_date_time();
                    f_write(&file, "\r\nModulo remoto disconnesso", 27, &bw);
                    f_write(&file, "\r\n--------------------------------------------------------------------------------", 82, &bw);
                    break;
                case REMOTE_CONNECT:
                    f_write_rtcc_date_time();
                    f_write(&file, "\r\nModulo remoto connesso", 24, &bw);
                    f_write(&file, "\r\n--------------------------------------------------------------------------------", 82, &bw);
                    break;
                case REMOTE_ELSE: 
                    f_write_rtcc_date_time();
                    f_write(&file, "\r\nModulo remoto else", 20, &bw);
                    f_write(&file, "\r\n--------------------------------------------------------------------------------", 82, &bw);
                    break;
                case HMTRP_DATA:
                    f_write_rtcc_date_time();
                    f_write(&file, "\r\nHMTRP data: ", 14, &bw);
                    for (unsigned char _i = 0; _i < HMTRP_BUFFER_LENGTH; _i++){
                        
                        _temp = (hmtrp_buffer[_i] >> 4) & 0x0F;
                        if (_temp < 0x0A)
                            _temp += '0';
                        else 
                            _temp += 0x37;   

                        f_write(&file, &_temp, 1, &bw);
                            
                        _temp = (hmtrp_buffer[_i]) & 0x0F;
                        if (_temp < 0x0A)
                            _temp += '0';
                        else 
                            _temp += 0x37; 

                        f_write(&file, &_temp, 1, &bw);
                        f_write(&file, " ", 1, &bw);
                    }
                    f_write(&file, " String received: ", 18, &bw);
                    _temp = hmtrp_string_received + '0';
                    f_write(&file, &_temp, 1, &bw);

                    f_write(&file, " Count: ", 8, &bw);
                    
                    _temp = (hmtrp_timeout_counter>>12) & 0x0F;
                                        
                    if (_temp < 0x0A)
                        _temp += '0';
                    else 
                        _temp += 0x37;   
                    f_write(&file, &_temp, 1, &bw);
                    
                    _temp = (hmtrp_timeout_counter>>8) & 0x0F;
                                        
                    if (_temp < 0x0A)
                        _temp += '0';
                    else 
                        _temp += 0x37;   
                    f_write(&file, &_temp, 1, &bw);
                    
                    _temp = (hmtrp_timeout_counter>>4) & 0x0F;
                                        
                    if (_temp < 0x0A)
                        _temp += '0';
                    else 
                        _temp += 0x37;   
                    f_write(&file, &_temp, 1, &bw);
                    
                    _temp = (hmtrp_timeout_counter) & 0x0F;
                                        
                    if (_temp < 0x0A)
                        _temp += '0';
                    else 
                        _temp += 0x37;   
                    f_write(&file, &_temp, 1, &bw);
                    
                    
                    f_write(&file, " Max: ", 6, &bw);
                    
                     _temp = (time_refresh_remote_sensors>>12) & 0x0F;
                                        
                    if (_temp < 0x0A)
                        _temp += '0';
                    else 
                        _temp += 0x37;   
                    f_write(&file, &_temp, 1, &bw);
                    
                    _temp = (time_refresh_remote_sensors>>8) & 0x0F;
                                        
                    if (_temp < 0x0A)
                        _temp += '0';
                    else 
                        _temp += 0x37;   
                    f_write(&file, &_temp, 1, &bw);
                    
                    _temp = (time_refresh_remote_sensors>>4) & 0x0F;
                                        
                    if (_temp < 0x0A)
                        _temp += '0';
                    else 
                        _temp += 0x37;   
                    f_write(&file, &_temp, 1, &bw);
                    
                    _temp = (time_refresh_remote_sensors) & 0x0F;
                                        
                    if (_temp < 0x0A)
                        _temp += '0';
                    else 
                        _temp += 0x37;   
                    f_write(&file, &_temp, 1, &bw);                            
                    
                    break;
                case REMOTE_TEST_SENS:
                    f_write_rtcc_date_time();
                    f_write(&file, "\r\nTest sensori remoti", 21, &bw);
                    break;
                case SENSOR_ANOMALY_LOC:
                    f_write_rtcc_date_time();
                    f_write(&file, "\r\nAnomalia sensori locali", 26, &bw);
                    f_write(&file, "\r\n--------------------------------------------------------------------------------", 82, &bw);    
                    break;
                case SENSOR_ANOMALY_REM:
                    f_write_rtcc_date_time();
                    f_write(&file, "\r\nAnomalia sensori remoti", 26, &bw);
                    f_write(&file, "\r\n--------------------------------------------------------------------------------", 82, &bw);    
                    break;
                case DCF77_STOPPED:
                    f_write_rtcc_date_time();
                    f_write(&file, "\r\nSincronizzazione DCF77 fermata", 32, &bw);
                    f_write(&file, "\r\n--------------------------------------------------------------------------------", 82, &bw);    
                    break;
                case TIME_START_STATISTIC:
                    f_write_rtcc_date_time();           // ora attuale
                    f_write(&file, "\r\nOra salvata statistiche\r\n", 27, &bw);   
                    f_write_rtcc_date_time_start();     // ora salvata
                    f_write(&file, "\r\n--------------------------------------------------------------------------------", 82, &bw);    
                    break;
                case WIFI_TIMEOUT:
                    f_write(&file, "Chiusura connessione per Time Out", 33, &bw);
                    f_write(&file, "\r\n--------------------------------------------------------------------------------", 82, &bw);
                    break;
                case DCF77_RECEIVED_SINGLE:
                    f_write(&file, "DCF77_received: ", 16, &bw);                      
                    f_write_dcf77_date_time(dcf77_time_0);
            }
            f_write(&file, "\r\n", 2, &bw);   
            f_close(&file);								/* Close the file */
        }
    }
}


void f_write_rtcc_date_time(void){
    unsigned char _temp = 0;
    
    rtcc_data _debug_rtcc_time;
    
    _debug_rtcc_time = RTCC_read_all();
    
    _temp = (_debug_rtcc_time.day >> 4) & 0x0F;
    _temp += '0';
    f_write(&file, &_temp, 1, &bw);
    _temp = (_debug_rtcc_time.day) & 0x0F;
    _temp += '0';
    f_write(&file, &_temp, 1, &bw);
    f_write(&file, "/", 1, &bw);
    _temp = (_debug_rtcc_time.month >> 4) & 0x0F;
    _temp += '0';
    f_write(&file, &_temp, 1, &bw);
    _temp = (_debug_rtcc_time.month) & 0x0F;
    _temp += '0';
    f_write(&file, &_temp, 1, &bw);
    f_write(&file, "/", 1, &bw);
    _temp = (_debug_rtcc_time.year >> 4) & 0x0F;
    _temp += '0';
    f_write(&file, &_temp, 1, &bw);
    _temp = (_debug_rtcc_time.year) & 0x0F;
    _temp += '0';
    f_write(&file, &_temp, 1, &bw);
    f_write(&file, " ", 1, &bw);
    _temp = (_debug_rtcc_time.day_w) & 0x0F;
    _temp += '0';
    f_write(&file, &_temp, 1, &bw);
    f_write(&file, " ", 1, &bw);
    _temp = (_debug_rtcc_time.hours >> 4) & 0x0F;
    _temp += '0';
    f_write(&file, &_temp, 1, &bw);
    _temp = (_debug_rtcc_time.hours) & 0x0F;
    _temp += '0';
    f_write(&file, &_temp, 1, &bw);
    f_write(&file, ":", 1, &bw);
    _temp = (_debug_rtcc_time.minutes >> 4) & 0x0F;
    _temp += '0';
    f_write(&file, &_temp, 1, &bw);
    _temp = (_debug_rtcc_time.minutes) & 0x0F;
    _temp += '0';
    f_write(&file, &_temp, 1, &bw);
    f_write(&file, ":", 1, &bw);
    _temp = (_debug_rtcc_time.seconds >> 4) & 0x0F;
    _temp += '0';
    f_write(&file, &_temp, 1, &bw);
    _temp = (_debug_rtcc_time.seconds) & 0x0F;
    _temp += '0';
    f_write(&file, &_temp, 1, &bw);
    
    if (cet_cest_flag == 0)
        f_write(&file, " CET", 4, &bw);
    else 
        f_write(&file, " CEST", 5, &bw);
}

void f_write_rtcc_date_time_start(void){
    unsigned char _temp = 0;
    
    _temp = (rtcc_time_start.day >> 4) & 0x0F;
    _temp += '0';
    f_write(&file, &_temp, 1, &bw);
    _temp = (rtcc_time_start.day) & 0x0F;
    _temp += '0';
    f_write(&file, &_temp, 1, &bw);
    f_write(&file, "/", 1, &bw);
    _temp = (rtcc_time_start.month >> 4) & 0x0F;
    _temp += '0';
    f_write(&file, &_temp, 1, &bw);
    _temp = (rtcc_time_start.month) & 0x0F;
    _temp += '0';
    f_write(&file, &_temp, 1, &bw);
    f_write(&file, "/", 1, &bw);
    _temp = (rtcc_time_start.year >> 4) & 0x0F;
    _temp += '0';
    f_write(&file, &_temp, 1, &bw);
    _temp = (rtcc_time_start.year) & 0x0F;
    _temp += '0';
    f_write(&file, &_temp, 1, &bw);
    f_write(&file, " ", 1, &bw);
    _temp = (rtcc_time_start.day_w) & 0x0F;
    _temp += '0';
    f_write(&file, &_temp, 1, &bw);
    f_write(&file, " ", 1, &bw);
    _temp = (rtcc_time_start.hours >> 4) & 0x0F;
    _temp += '0';
    f_write(&file, &_temp, 1, &bw);
    _temp = (rtcc_time_start.hours) & 0x0F;
    _temp += '0';
    f_write(&file, &_temp, 1, &bw);
    f_write(&file, ":", 1, &bw);
    _temp = (rtcc_time_start.minutes >> 4) & 0x0F;
    _temp += '0';
    f_write(&file, &_temp, 1, &bw);
    _temp = (rtcc_time_start.minutes) & 0x0F;
    _temp += '0';
    f_write(&file, &_temp, 1, &bw);
    f_write(&file, ":", 1, &bw);
    _temp = (rtcc_time_start.seconds >> 4) & 0x0F;
    _temp += '0';
    f_write(&file, &_temp, 1, &bw);
    _temp = (rtcc_time_start.seconds) & 0x0F;
    _temp += '0';
    f_write(&file, &_temp, 1, &bw);
    
    if (cet_cest_flag == 0)
        f_write(&file, " CET", 4, &bw);
    else 
        f_write(&file, " CEST", 5, &bw);
}

void f_write_dcf77_date_time (dcf77_decoded_data _time){
    unsigned char _temp = 0;
    _temp = (_time.day >> 4) & 0x0F;
    _temp += '0';
    f_write(&file, &_temp, 1, &bw);
    _temp = (_time.day) & 0x0F;
    _temp += '0';
    f_write(&file, &_temp, 1, &bw);
    f_write(&file, "/", 1, &bw);
    _temp = (_time.month >> 4) & 0x0F;
    _temp += '0';
    f_write(&file, &_temp, 1, &bw);
    _temp = (_time.month) & 0x0F;
    _temp += '0';
    f_write(&file, &_temp, 1, &bw);
    f_write(&file, "/", 1, &bw);
    _temp = (_time.year >> 4) & 0x0F;
    _temp += '0';
    f_write(&file, &_temp, 1, &bw);
    _temp = (_time.year) & 0x0F;
    _temp += '0';
    f_write(&file, &_temp, 1, &bw);
    f_write(&file, " ", 1, &bw);
    _temp = (_time.day_w) & 0x0F;
    _temp += '0';
    f_write(&file, &_temp, 1, &bw);
    f_write(&file, " ", 1, &bw);
    _temp = (_time.hours >> 4) & 0x0F;
    _temp += '0';
    f_write(&file, &_temp, 1, &bw);
    _temp = (_time.hours) & 0x0F;
    _temp += '0';
    f_write(&file, &_temp, 1, &bw);
    f_write(&file, ":", 1, &bw);
    _temp = (_time.minutes >> 4) & 0x0F;
    _temp += '0';
    f_write(&file, &_temp, 1, &bw);
    _temp = (_time.minutes) & 0x0F;
    _temp += '0';
    f_write(&file, &_temp, 1, &bw);
    f_write(&file, " ", 1, &bw);
    for (unsigned char _i=0; _i<5; _i++){
        _temp = (_time.flag_bits >> 4 -_i) & 0b0000001;
        _temp += '0';
        f_write(&file, &_temp, 1, &bw);   
    }
    f_write(&file, " ", 1, &bw);
    for (unsigned char _i=0; _i<14; _i++){
        _temp = (_time.meteo >> 13 -_i) & 0b0000001;
        _temp += '0';
        f_write(&file, &_temp, 1, &bw);   
    }
}
#endif